render

package
v1.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 7, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	BoardLaneColorMaybe    = "Blue"
	BoardLaneColorComplete = "Gray"
)

Variables

This section is empty.

Functions

func BoardView

func BoardView(boardName string, columns []api.Column, cards []api.Card, width int) string

BoardView renders a kanban board with columns and cards.

func TerminalWidth

func TerminalWidth() int

TerminalWidth returns the width of the terminal, defaulting to 80.

Types

This section is empty.

Jump to